import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/Saikiran2029/81bc634446a0dc0d7fb5f6fc80e10685/raw/7ad1e131e32b931962450b89b18b594a19036d15/tourists%2520visited.csv'
const width = 950;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };



const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.peoplevisited;
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(2, 10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.country))
    .range([2, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.peoplevisited)])
    .range([3, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="blue" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 2}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.country}
            x={0}
            y={yScale(d.country)}
            width={xScale(d.peoplevisited)}
            height={yScale.bandwidth() -2}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);